# Copyright (c) 2012 Cloudera, Inc. All rights reserved.

from cmf.monitor.jmx_beans import JsonParserJmx

class JsonParser(JsonParserJmx):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what we expect.
    """
    JsonParserJmx.__init__(self, json_dict, 'JOURNALNODE')

# Collected from bolt CDH4 JN on 10/18/2012.
SAMPLE = r"""
{
  "beans" : [ {
    "name" : "java.lang:type=MemoryPool,name=PS Eden Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Eden Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 7405568,
      "init" : 197722112,
      "max" : 344915968,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 197722112,
      "init" : 197722112,
      "max" : 347734016,
      "used" : 197722112
    },
    "Usage" : {
      "committed" : 7405568,
      "init" : 197722112,
      "max" : 344915968,
      "used" : 6330720
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=Memory",
    "modelerType" : "sun.management.MemoryImpl",
    "Verbose" : false,
    "HeapMemoryUsage" : {
      "committed" : 536870912,
      "init" : 790667136,
      "max" : 932118528,
      "used" : 164109712
    },
    "NonHeapMemoryUsage" : {
      "committed" : 34537472,
      "init" : 24313856,
      "max" : 136314880,
      "used" : 34426576
    },
    "ObjectPendingFinalizationCount" : 0
  }, {
    "name" : "Hadoop:service=JournalNode,name=Journal-journalhdfs1",
    "modelerType" : "Journal-journalhdfs1",
    "tag.Context" : "dfs",
    "tag.Hostname" : "c0805.hal.cloudera.com",
    "Syncs60sNumOps" : 4,
    "Syncs60s50thPercentileLatencyMicros" : 2493,
    "Syncs60s75thPercentileLatencyMicros" : 2764,
    "Syncs60s90thPercentileLatencyMicros" : 2764,
    "Syncs60s95thPercentileLatencyMicros" : 2764,
    "Syncs60s99thPercentileLatencyMicros" : 2764,
    "Syncs300sNumOps" : 446,
    "Syncs300s50thPercentileLatencyMicros" : 6751,
    "Syncs300s75thPercentileLatencyMicros" : 8262,
    "Syncs300s90thPercentileLatencyMicros" : 11287,
    "Syncs300s95thPercentileLatencyMicros" : 15182,
    "Syncs300s99thPercentileLatencyMicros" : 20747,
    "Syncs3600sNumOps" : 11765,
    "Syncs3600s50thPercentileLatencyMicros" : 5293,
    "Syncs3600s75thPercentileLatencyMicros" : 7636,
    "Syncs3600s90thPercentileLatencyMicros" : 9279,
    "Syncs3600s95thPercentileLatencyMicros" : 14367,
    "Syncs3600s99thPercentileLatencyMicros" : 26687,
    "BatchesWritten" : 1096449,
    "TxnsWritten" : 3486548,
    "BytesWritten" : 450752017,
    "BatchesWrittenWhileLagging" : 15095,
    "LastPromisedEpoch" : 27,
    "LastWriterEpoch" : 27,
    "CurrentLagTxns" : 0,
    "LastWrittenTxId" : 517148448
  }, {
    "name" : "Hadoop:service=JournalNode,name=JvmMetrics",
    "modelerType" : "JvmMetrics",
    "tag.Context" : "jvm",
    "tag.ProcessName" : "JournalNode",
    "tag.SessionId" : null,
    "tag.Hostname" : "c0805.hal.cloudera.com",
    "MemNonHeapUsedM" : 32.83174,
    "MemNonHeapCommittedM" : 32.9375,
    "MemHeapUsedM" : 156.52806,
    "MemHeapCommittedM" : 512.0,
    "GcCount" : 845,
    "GcTimeMillis" : 2120,
    "ThreadsNew" : 0,
    "ThreadsRunnable" : 7,
    "ThreadsBlocked" : 0,
    "ThreadsWaiting" : 10,
    "ThreadsTimedWaiting" : 6,
    "ThreadsTerminated" : 0,
    "LogFatal" : 0,
    "LogError" : 0,
    "LogWarn" : 1,
    "LogInfo" : 3249
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Survivor Space",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Survivor Space",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 2293760,
      "init" : 32899072,
      "max" : 2293760,
      "used" : 1310752
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep", "PS Scavenge" ],
    "PeakUsage" : {
      "committed" : 32899072,
      "init" : 32899072,
      "max" : 32899072,
      "used" : 4825200
    },
    "Usage" : {
      "committed" : 2293760,
      "init" : 32899072,
      "max" : 2293760,
      "used" : 1310752
    },
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdSupported" : false
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS MarkSweep",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : null,
    "CollectionCount" : 0,
    "CollectionTime" : 0,
    "Name" : "PS MarkSweep",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space", "PS Old Gen", "PS Perm Gen" ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=Code Cache",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "Code Cache",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : null,
    "MemoryManagerNames" : [ "CodeCacheManager" ],
    "PeakUsage" : {
      "committed" : 3145728,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 3096448
    },
    "Usage" : {
      "committed" : 3145728,
      "init" : 2555904,
      "max" : 50331648,
      "used" : 3088192
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdSupported" : false,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "Hadoop:service=JournalNode,name=UgiMetrics",
    "modelerType" : "UgiMetrics",
    "tag.Context" : "ugi",
    "tag.Hostname" : "c0805.hal.cloudera.com",
    "LoginSuccessNumOps" : 0,
    "LoginSuccessAvgTime" : 0.0,
    "LoginFailureNumOps" : 0,
    "LoginFailureAvgTime" : 0.0
  }, {
    "name" : "java.lang:type=Runtime",
    "modelerType" : "sun.management.RuntimeImpl",
    "Name" : "1998@c0805.hal.cloudera.com",
    "ClassPath" : "/var/run/cloudera-scm-agent/process/50143-hdfs-JOURNALNODE:/usr/lib/hadoop/lib/jackson-jaxrs-1.8.8.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/mockito-all-1.8.5.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/log4j-1.2.17.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/jline-0.9.94.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/jsr305-1.3.9.jar:/usr/lib/hadoop/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/jaxb-api-2.2.2.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/stax-api-1.0.1.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/jsch-0.1.42.jar:/usr/lib/hadoop/lib/commons-net-3.1.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jackson-xc-1.8.8.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/hue-plugins-2.1.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/guava-11.0.2.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/.//hadoop-auth.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop/.//hadoop-annotations-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-auth-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common.jar:/usr/lib/hadoop/.//hadoop-annotations.jar:/usr/share/cmf/lib/plugins/event-publish-4.1.0-SNAPSHOT-shaded.jar:/usr/lib/hadoop-hdfs/./:/usr/lib/hadoop-hdfs/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-codec-1.4.jar:/usr/lib/hadoop-hdfs/lib/log4j-1.2.17.jar:/usr/lib/hadoop-hdfs/lib/commons-io-2.1.jar:/usr/lib/hadoop-hdfs/lib/jsp-api-2.1.jar:/usr/lib/hadoop-hdfs/lib/jline-0.9.94.jar:/usr/lib/hadoop-hdfs/lib/commons-cli-1.2.jar:/usr/lib/hadoop-hdfs/lib/jsr305-1.3.9.jar:/usr/lib/hadoop-hdfs/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-core-1.8.jar:/usr/lib/hadoop-hdfs/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop-hdfs/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/servlet-api-2.5.jar:/usr/lib/hadoop-hdfs/lib/asm-3.2.jar:/usr/lib/hadoop-hdfs/lib/commons-el-1.0.jar:/usr/lib/hadoop-hdfs/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-hdfs/lib/commons-lang-2.5.jar:/usr/lib/hadoop-hdfs/lib/jersey-server-1.8.jar:/usr/lib/hadoop-hdfs/lib/guava-11.0.2.jar:/usr/lib/hadoop-hdfs/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/lib/xmlenc-0.52.jar:/usr/lib/hadoop-hdfs/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop-hdfs/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/lib/javax.inject-1.jar:/usr/lib/hadoop-yarn/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/log4j-1.2.17.jar:/usr/lib/hadoop-yarn/lib/aopalliance-1.0.jar:/usr/lib/hadoop-yarn/lib/commons-io-2.1.jar:/usr/lib/hadoop-yarn/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-yarn/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-yarn/lib/jersey-core-1.8.jar:/usr/lib/hadoop-yarn/lib/guice-3.0.jar:/usr/lib/hadoop-yarn/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-yarn/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-yarn/lib/asm-3.2.jar:/usr/lib/hadoop-yarn/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-yarn/lib/jersey-server-1.8.jar:/usr/lib/hadoop-yarn/lib/paranamer-2.3.jar:/usr/lib/hadoop-yarn/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site.jar:/usr/lib/hadoop-mapreduce/lib/javax.inject-1.jar:/usr/lib/hadoop-mapreduce/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/log4j-1.2.17.jar:/usr/lib/hadoop-mapreduce/lib/aopalliance-1.0.jar:/usr/lib/hadoop-mapreduce/lib/commons-io-2.1.jar:/usr/lib/hadoop-mapreduce/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-mapreduce/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-mapreduce/lib/jersey-core-1.8.jar:/usr/lib/hadoop-mapreduce/lib/guice-3.0.jar:/usr/lib/hadoop-mapreduce/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-mapreduce/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-mapreduce/lib/asm-3.2.jar:/usr/lib/hadoop-mapreduce/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-mapreduce/lib/jersey-server-1.8.jar:/usr/lib/hadoop-mapreduce/lib/paranamer-2.3.jar:/usr/lib/hadoop-mapreduce/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix-2.0.0-cdh4.1.1-SNAPSHOT.jar",
    "StartTime" : 1350410710660,
    "BootClassPath" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes",
    "LibraryPath" : "/usr/lib/hadoop/lib/native",
    "VmName" : "Java HotSpot(TM) 64-Bit Server VM",
    "VmVendor" : "Sun Microsystems Inc.",
    "VmVersion" : "20.6-b01",
    "BootClassPathSupported" : true,
    "InputArguments" : [ "-Dproc_journalnode", "-Xmx1000m", "-Djava.net.preferIPv4Stack=true", "-Dhadoop.log.dir=/var/log/hadoop-hdfs", "-Dhadoop.log.file=hadoop-cmf-hdfs1-JOURNALNODE-c0805.hal.cloudera.com.log.out", "-Dhadoop.home.dir=/usr/lib/hadoop", "-Dhadoop.id.str=hdfs", "-Dhadoop.root.logger=INFO,RFA", "-Djava.library.path=/usr/lib/hadoop/lib/native", "-Dhadoop.policy.file=hadoop-policy.xml", "-Djava.net.preferIPv4Stack=true", "-Dhadoop.security.logger=INFO,RFAS" ],
    "ManagementSpecVersion" : "1.2",
    "SpecName" : "Java Virtual Machine Specification",
    "SpecVendor" : "Sun Microsystems Inc.",
    "SpecVersion" : "1.0",
    "SystemProperties" : [ {
      "key" : "java.ext.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/ext:/usr/java/packages/lib/ext"
    }, {
      "key" : "hadoop.home.dir",
      "value" : "/usr/lib/hadoop"
    }, {
      "key" : "java.vm.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "user.timezone",
      "value" : "US/Pacific"
    }, {
      "key" : "java.vm.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "hadoop.id.str",
      "value" : "hdfs"
    }, {
      "key" : "user.name",
      "value" : "hdfs"
    }, {
      "key" : "java.vm.specification.name",
      "value" : "Java Virtual Machine Specification"
    }, {
      "key" : "user.dir",
      "value" : "/var/run/cloudera-scm-agent/process/50143-hdfs-JOURNALNODE"
    }, {
      "key" : "user.country",
      "value" : "US"
    }, {
      "key" : "user.language",
      "value" : "en"
    }, {
      "key" : "java.specification.version",
      "value" : "1.6"
    }, {
      "key" : "hadoop.log.file",
      "value" : "hadoop-cmf-hdfs1-JOURNALNODE-c0805.hal.cloudera.com.log.out"
    }, {
      "key" : "hadoop.policy.file",
      "value" : "hadoop-policy.xml"
    }, {
      "key" : "sun.cpu.endian",
      "value" : "little"
    }, {
      "key" : "java.home",
      "value" : "/usr/java/jdk1.6.0_31/jre"
    }, {
      "key" : "java.net.preferIPv4Stack",
      "value" : "true"
    }, {
      "key" : "sun.jnu.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "file.separator",
      "value" : "/"
    }, {
      "key" : "java.vendor.url",
      "value" : "http://java.sun.com/"
    }, {
      "key" : "java.awt.graphicsenv",
      "value" : "sun.awt.X11GraphicsEnvironment"
    }, {
      "key" : "hadoop.log.dir",
      "value" : "/var/log/hadoop-hdfs"
    }, {
      "key" : "os.arch",
      "value" : "amd64"
    }, {
      "key" : "java.io.tmpdir",
      "value" : "/tmp"
    }, {
      "key" : "proc_journalnode",
      "value" : ""
    }, {
      "key" : "java.runtime.name",
      "value" : "Java(TM) SE Runtime Environment"
    }, {
      "key" : "java.awt.printerjob",
      "value" : "sun.print.PSPrinterJob"
    }, {
      "key" : "file.encoding",
      "value" : "UTF-8"
    }, {
      "key" : "java.version",
      "value" : "1.6.0_31"
    }, {
      "key" : "java.vendor.url.bug",
      "value" : "http://java.sun.com/cgi-bin/bugreport.cgi"
    }, {
      "key" : "java.vm.specification.version",
      "value" : "1.0"
    }, {
      "key" : "file.encoding.pkg",
      "value" : "sun.io"
    }, {
      "key" : "sun.java.command",
      "value" : "org.apache.hadoop.hdfs.qjournal.server.JournalNode"
    }, {
      "key" : "sun.java.launcher",
      "value" : "SUN_STANDARD"
    }, {
      "key" : "path.separator",
      "value" : ":"
    }, {
      "key" : "java.runtime.version",
      "value" : "1.6.0_31-b04"
    }, {
      "key" : "java.class.path",
      "value" : "/var/run/cloudera-scm-agent/process/50143-hdfs-JOURNALNODE:/usr/lib/hadoop/lib/jackson-jaxrs-1.8.8.jar:/usr/lib/hadoop/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/mockito-all-1.8.5.jar:/usr/lib/hadoop/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop/lib/commons-codec-1.4.jar:/usr/lib/hadoop/lib/log4j-1.2.17.jar:/usr/lib/hadoop/lib/commons-beanutils-core-1.8.0.jar:/usr/lib/hadoop/lib/commons-configuration-1.6.jar:/usr/lib/hadoop/lib/commons-io-2.1.jar:/usr/lib/hadoop/lib/jsp-api-2.1.jar:/usr/lib/hadoop/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop/lib/junit-4.8.2.jar:/usr/lib/hadoop/lib/jline-0.9.94.jar:/usr/lib/hadoop/lib/commons-digester-1.8.jar:/usr/lib/hadoop/lib/kfs-0.3.jar:/usr/lib/hadoop/lib/commons-cli-1.2.jar:/usr/lib/hadoop/lib/jsr305-1.3.9.jar:/usr/lib/hadoop/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop/lib/commons-httpclient-3.1.jar:/usr/lib/hadoop/lib/jersey-core-1.8.jar:/usr/lib/hadoop/lib/slf4j-log4j12-1.6.1.jar:/usr/lib/hadoop/lib/jaxb-api-2.2.2.jar:/usr/lib/hadoop/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop/lib/commons-beanutils-1.7.0.jar:/usr/lib/hadoop/lib/activation-1.1.jar:/usr/lib/hadoop/lib/jersey-json-1.8.jar:/usr/lib/hadoop/lib/slf4j-api-1.6.1.jar:/usr/lib/hadoop/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop/lib/servlet-api-2.5.jar:/usr/lib/hadoop/lib/stax-api-1.0.1.jar:/usr/lib/hadoop/lib/jaxb-impl-2.2.3-1.jar:/usr/lib/hadoop/lib/jsch-0.1.42.jar:/usr/lib/hadoop/lib/commons-net-3.1.jar:/usr/lib/hadoop/lib/asm-3.2.jar:/usr/lib/hadoop/lib/commons-el-1.0.jar:/usr/lib/hadoop/lib/jackson-xc-1.8.8.jar:/usr/lib/hadoop/lib/jets3t-0.6.1.jar:/usr/lib/hadoop/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop/lib/commons-collections-3.2.1.jar:/usr/lib/hadoop/lib/hue-plugins-2.1.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/commons-lang-2.5.jar:/usr/lib/hadoop/lib/jersey-server-1.8.jar:/usr/lib/hadoop/lib/commons-math-2.1.jar:/usr/lib/hadoop/lib/guava-11.0.2.jar:/usr/lib/hadoop/lib/paranamer-2.3.jar:/usr/lib/hadoop/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/lib/xmlenc-0.52.jar:/usr/lib/hadoop/lib/jettison-1.1.jar:/usr/lib/hadoop/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop/lib/jasper-compiler-5.5.23.jar:/usr/lib/hadoop/.//hadoop-auth.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop/.//hadoop-annotations-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-auth-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop/.//hadoop-common.jar:/usr/lib/hadoop/.//hadoop-annotations.jar:/usr/share/cmf/lib/plugins/event-publish-4.1.0-SNAPSHOT-shaded.jar:/usr/lib/hadoop-hdfs/./:/usr/lib/hadoop-hdfs/lib/jetty-util-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/commons-codec-1.4.jar:/usr/lib/hadoop-hdfs/lib/log4j-1.2.17.jar:/usr/lib/hadoop-hdfs/lib/commons-io-2.1.jar:/usr/lib/hadoop-hdfs/lib/jsp-api-2.1.jar:/usr/lib/hadoop-hdfs/lib/jline-0.9.94.jar:/usr/lib/hadoop-hdfs/lib/commons-cli-1.2.jar:/usr/lib/hadoop-hdfs/lib/jsr305-1.3.9.jar:/usr/lib/hadoop-hdfs/lib/jetty-6.1.26.cloudera.2.jar:/usr/lib/hadoop-hdfs/lib/jersey-core-1.8.jar:/usr/lib/hadoop-hdfs/lib/jasper-runtime-5.5.23.jar:/usr/lib/hadoop-hdfs/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-hdfs/lib/servlet-api-2.5.jar:/usr/lib/hadoop-hdfs/lib/asm-3.2.jar:/usr/lib/hadoop-hdfs/lib/commons-el-1.0.jar:/usr/lib/hadoop-hdfs/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-hdfs/lib/commons-lang-2.5.jar:/usr/lib/hadoop-hdfs/lib/jersey-server-1.8.jar:/usr/lib/hadoop-hdfs/lib/guava-11.0.2.jar:/usr/lib/hadoop-hdfs/lib/zookeeper-3.4.3-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-hdfs/lib/xmlenc-0.52.jar:/usr/lib/hadoop-hdfs/lib/commons-logging-1.1.1.jar:/usr/lib/hadoop-hdfs/lib/commons-daemon-1.0.3.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs.jar:/usr/lib/hadoop-hdfs/.//hadoop-hdfs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/lib/javax.inject-1.jar:/usr/lib/hadoop-yarn/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/log4j-1.2.17.jar:/usr/lib/hadoop-yarn/lib/aopalliance-1.0.jar:/usr/lib/hadoop-yarn/lib/commons-io-2.1.jar:/usr/lib/hadoop-yarn/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-yarn/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-yarn/lib/jersey-core-1.8.jar:/usr/lib/hadoop-yarn/lib/guice-3.0.jar:/usr/lib/hadoop-yarn/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-yarn/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-yarn/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-yarn/lib/asm-3.2.jar:/usr/lib/hadoop-yarn/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-yarn/lib/jersey-server-1.8.jar:/usr/lib/hadoop-yarn/lib/paranamer-2.3.jar:/usr/lib/hadoop-yarn/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-common.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-api.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-resourcemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-applications-distributedshell.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-tests-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-web-proxy.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-server-nodemanager.jar:/usr/lib/hadoop-yarn/.//hadoop-yarn-site.jar:/usr/lib/hadoop-mapreduce/lib/javax.inject-1.jar:/usr/lib/hadoop-mapreduce/lib/jackson-core-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/log4j-1.2.17.jar:/usr/lib/hadoop-mapreduce/lib/aopalliance-1.0.jar:/usr/lib/hadoop-mapreduce/lib/commons-io-2.1.jar:/usr/lib/hadoop-mapreduce/lib/avro-1.7.1.cloudera.2.jar:/usr/lib/hadoop-mapreduce/lib/jersey-guice-1.8.jar:/usr/lib/hadoop-mapreduce/lib/jersey-core-1.8.jar:/usr/lib/hadoop-mapreduce/lib/guice-3.0.jar:/usr/lib/hadoop-mapreduce/lib/jackson-mapper-asl-1.8.8.jar:/usr/lib/hadoop-mapreduce/lib/netty-3.2.4.Final.jar:/usr/lib/hadoop-mapreduce/lib/guice-servlet-3.0.jar:/usr/lib/hadoop-mapreduce/lib/asm-3.2.jar:/usr/lib/hadoop-mapreduce/lib/protobuf-java-2.4.0a.jar:/usr/lib/hadoop-mapreduce/lib/jersey-server-1.8.jar:/usr/lib/hadoop-mapreduce/lib/paranamer-2.3.jar:/usr/lib/hadoop-mapreduce/lib/snappy-java-1.0.4.1.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT-tests.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix.jar:/usr/lib/hadoop-mapreduce/.//hadoop-archives-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-common-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-core-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-datajoin.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-app.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-jobclient-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming.jar:/usr/lib/hadoop-mapreduce/.//hadoop-distcp.jar:/usr/lib/hadoop-mapreduce/.//hadoop-rumen-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-shuffle-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-examples-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-streaming-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-mapreduce-client-hs.jar:/usr/lib/hadoop-mapreduce/.//hadoop-extras-2.0.0-cdh4.1.1-SNAPSHOT.jar:/usr/lib/hadoop-mapreduce/.//hadoop-gridmix-2.0.0-cdh4.1.1-SNAPSHOT.jar"
    }, {
      "key" : "os.name",
      "value" : "Linux"
    }, {
      "key" : "hadoop.security.logger",
      "value" : "INFO,RFAS"
    }, {
      "key" : "line.separator",
      "value" : "\n"
    }, {
      "key" : "os.version",
      "value" : "2.6.32-279.el6.x86_64"
    }, {
      "key" : "sun.arch.data.model",
      "value" : "64"
    }, {
      "key" : "java.class.version",
      "value" : "50.0"
    }, {
      "key" : "sun.io.unicode.encoding",
      "value" : "UnicodeLittle"
    }, {
      "key" : "java.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.boot.class.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/resources.jar:/usr/java/jdk1.6.0_31/jre/lib/rt.jar:/usr/java/jdk1.6.0_31/jre/lib/sunrsasign.jar:/usr/java/jdk1.6.0_31/jre/lib/jsse.jar:/usr/java/jdk1.6.0_31/jre/lib/jce.jar:/usr/java/jdk1.6.0_31/jre/lib/charsets.jar:/usr/java/jdk1.6.0_31/jre/lib/modules/jdk.boot.jar:/usr/java/jdk1.6.0_31/jre/classes"
    }, {
      "key" : "java.vm.info",
      "value" : "mixed mode"
    }, {
      "key" : "java.specification.name",
      "value" : "Java Platform API Specification"
    }, {
      "key" : "java.vm.name",
      "value" : "Java HotSpot(TM) 64-Bit Server VM"
    }, {
      "key" : "java.vm.version",
      "value" : "20.6-b01"
    }, {
      "key" : "sun.boot.library.path",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/amd64"
    }, {
      "key" : "hadoop.root.logger",
      "value" : "INFO,RFA"
    }, {
      "key" : "java.endorsed.dirs",
      "value" : "/usr/java/jdk1.6.0_31/jre/lib/endorsed"
    }, {
      "key" : "sun.os.patch.level",
      "value" : "unknown"
    }, {
      "key" : "sun.cpu.isalist",
      "value" : ""
    }, {
      "key" : "user.home",
      "value" : "/usr/lib/hadoop-0.20"
    }, {
      "key" : "java.library.path",
      "value" : "/usr/lib/hadoop/lib/native"
    }, {
      "key" : "java.specification.vendor",
      "value" : "Sun Microsystems Inc."
    }, {
      "key" : "sun.management.compiler",
      "value" : "HotSpot 64-Bit Tiered Compilers"
    } ],
    "Uptime" : 182853534
  }, {
    "name" : "java.lang:type=ClassLoading",
    "modelerType" : "sun.management.ClassLoadingImpl",
    "LoadedClassCount" : 3572,
    "UnloadedClassCount" : 0,
    "TotalLoadedClassCount" : 3572,
    "Verbose" : false
  }, {
    "name" : "java.lang:type=Threading",
    "modelerType" : "sun.management.ThreadImpl",
    "ThreadAllocatedMemoryEnabled" : true,
    "ThreadAllocatedMemorySupported" : true,
    "DaemonThreadCount" : 16,
    "PeakThreadCount" : 25,
    "CurrentThreadCpuTimeSupported" : true,
    "ObjectMonitorUsageSupported" : true,
    "SynchronizerUsageSupported" : true,
    "ThreadContentionMonitoringEnabled" : false,
    "ThreadContentionMonitoringSupported" : true,
    "ThreadCpuTimeEnabled" : true,
    "AllThreadIds" : [ 31, 30, 28, 27, 26, 25, 24, 23, 22, 21, 18, 20, 19, 17, 16, 13, 12, 11, 10, 9, 4, 3, 2, 1 ],
    "CurrentThreadCpuTime" : 20040000000,
    "CurrentThreadUserTime" : 18310000000,
    "ThreadCount" : 24,
    "TotalStartedThreadCount" : 27,
    "ThreadCpuTimeSupported" : true
  }, {
    "name" : "Hadoop:service=JournalNode,name=MetricsSystem,sub=Control",
    "modelerType" : "org.apache.hadoop.metrics2.impl.MetricsSystemImpl"
  }, {
    "name" : "java.util.logging:type=Logging",
    "modelerType" : "java.util.logging.Logging",
    "LoggerNames" : [ "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioWorker", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.CompleteChannelFuture", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioProviderMetadata", "javax.management", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.DefaultChannelPipeline", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioClientSocketChannel", "sun.awt.AppContext", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.NioClientSocketPipelineSink", "global", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.SimpleChannelUpstreamHandler", "com.google.common.io.Closeables", "javax.management.mbeanserver", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.DefaultChannelFuture", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.DefaultNioSocketChannelConfig", "com.cloudera.cmf.event.shaded.org.jboss.netty.util.ThreadRenamingRunnable", "com.cloudera.cmf.event.shaded.org.jboss.netty.channel.socket.nio.SelectorUtil", "" ]
  }, {
    "name" : "java.lang:type=Compilation",
    "modelerType" : "sun.management.CompilationImpl",
    "Name" : "HotSpot 64-Bit Tiered Compilers",
    "CompilationTimeMonitoringSupported" : true,
    "TotalCompilationTime" : 9058
  }, {
    "name" : "Hadoop:service=JournalNode,name=RpcActivityForPort8485",
    "modelerType" : "RpcActivityForPort8485",
    "tag.port" : "8485",
    "tag.Context" : "rpc",
    "tag.Hostname" : "c0805.hal.cloudera.com",
    "ReceivedBytes" : 600149665,
    "SentBytes" : 12561291,
    "RpcQueueTimeNumOps" : 1102599,
    "RpcQueueTimeAvgTime" : 0.11111111111111113,
    "RpcProcessingTimeNumOps" : 1102599,
    "RpcProcessingTimeAvgTime" : 12.444444444444445,
    "RpcAuthenticationFailures" : 0,
    "RpcAuthenticationSuccesses" : 0,
    "RpcAuthorizationFailures" : 0,
    "RpcAuthorizationSuccesses" : 6131,
    "NumOpenConnections" : 0,
    "CallQueueLength" : 0
  }, {
    "name" : "com.sun.management:type=HotSpotDiagnostic",
    "modelerType" : "sun.management.HotSpotDiagnostic",
    "DiagnosticOptions" : [ {
      "name" : "HeapDumpBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpOnOutOfMemoryError",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "HeapDumpPath",
      "origin" : "DEFAULT",
      "value" : "",
      "writeable" : true
    }, {
      "name" : "CMSAbortablePrecleanWaitMillis",
      "origin" : "DEFAULT",
      "value" : "100",
      "writeable" : true
    }, {
      "name" : "CMSWaitDuration",
      "origin" : "DEFAULT",
      "value" : "2000",
      "writeable" : true
    }, {
      "name" : "PrintGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDetails",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCDateStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintGCTimeStamps",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramBeforeFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogramAfterFullGC",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintClassHistogram",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    }, {
      "name" : "PrintConcurrentLocks",
      "origin" : "DEFAULT",
      "value" : "false",
      "writeable" : true
    } ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Perm Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Perm Gen",
    "Type" : "NON_HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 31391744,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 31338384
    },
    "Usage" : {
      "committed" : 31391744,
      "init" : 21757952,
      "max" : 85983232,
      "used" : 31338384
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "Hadoop:service=JournalNode,name=RpcDetailedActivityForPort8485",
    "modelerType" : "RpcDetailedActivityForPort8485",
    "tag.port" : "8485",
    "tag.Context" : "rpcdetailed",
    "tag.Hostname" : "c0805.hal.cloudera.com",
    "GetEditLogManifestNumOps" : 3047,
    "GetEditLogManifestAvgTime" : 3.0,
    "GetJournalStateNumOps" : 2,
    "GetJournalStateAvgTime" : 0.0,
    "NewEpochNumOps" : 2,
    "NewEpochAvgTime" : 63.0,
    "PrepareRecoveryNumOps" : 2,
    "PrepareRecoveryAvgTime" : 13.0,
    "AcceptRecoveryNumOps" : 2,
    "AcceptRecoveryAvgTime" : 62.0,
    "FinalizeLogSegmentNumOps" : 1502,
    "FinalizeLogSegmentAvgTime" : 3.0,
    "StartLogSegmentNumOps" : 1502,
    "StartLogSegmentAvgTime" : 58.0,
    "JournalNumOps" : 1096449,
    "JournalAvgTime" : 8.0,
    "PurgeLogsNumOps" : 91,
    "PurgeLogsAvgTime" : 12.0
  }, {
    "name" : "java.lang:type=OperatingSystem",
    "modelerType" : "com.sun.management.UnixOperatingSystem",
    "MaxFileDescriptorCount" : 32768,
    "OpenFileDescriptorCount" : 181,
    "CommittedVirtualMemorySize" : 1623154688,
    "FreePhysicalMemorySize" : 24440229888,
    "FreeSwapSpaceSize" : 25370288128,
    "ProcessCpuTime" : 466500000000,
    "TotalPhysicalMemorySize" : 50602696704,
    "TotalSwapSpaceSize" : 25370288128,
    "Name" : "Linux",
    "Version" : "2.6.32-279.el6.x86_64",
    "AvailableProcessors" : 16,
    "Arch" : "amd64",
    "SystemLoadAverage" : 0.14
  }, {
    "name" : "java.lang:type=GarbageCollector,name=PS Scavenge",
    "modelerType" : "sun.management.GarbageCollectorImpl",
    "LastGcInfo" : {
      "GcThreadCount" : 13,
      "duration" : 2,
      "endTime" : 182732669,
      "id" : 845,
      "memoryUsageAfterGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 2293760,
          "init" : 32899072,
          "max" : 2293760,
          "used" : 1310752
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 527171584,
          "init" : 527171584,
          "max" : 699072512,
          "used" : 156468240
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 31195136,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 31094400
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 3145728,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 3087552
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 7405568,
          "init" : 197722112,
          "max" : 344915968,
          "used" : 0
        }
      } ],
      "memoryUsageBeforeGc" : [ {
        "key" : "PS Survivor Space",
        "value" : {
          "committed" : 2293760,
          "init" : 32899072,
          "max" : 2293760,
          "used" : 1245216
        }
      }, {
        "key" : "PS Old Gen",
        "value" : {
          "committed" : 527171584,
          "init" : 527171584,
          "max" : 699072512,
          "used" : 156419088
        }
      }, {
        "key" : "PS Perm Gen",
        "value" : {
          "committed" : 31195136,
          "init" : 21757952,
          "max" : 85983232,
          "used" : 31094400
        }
      }, {
        "key" : "Code Cache",
        "value" : {
          "committed" : 3145728,
          "init" : 2555904,
          "max" : 50331648,
          "used" : 3087552
        }
      }, {
        "key" : "PS Eden Space",
        "value" : {
          "committed" : 7405568,
          "init" : 197722112,
          "max" : 344915968,
          "used" : 7405568
        }
      } ],
      "startTime" : 182732667
    },
    "CollectionCount" : 845,
    "CollectionTime" : 2120,
    "Name" : "PS Scavenge",
    "Valid" : true,
    "MemoryPoolNames" : [ "PS Eden Space", "PS Survivor Space" ]
  }, {
    "name" : "java.lang:type=MemoryPool,name=PS Old Gen",
    "modelerType" : "sun.management.MemoryPoolImpl",
    "Name" : "PS Old Gen",
    "Type" : "HEAP",
    "Valid" : true,
    "CollectionUsage" : {
      "committed" : 0,
      "init" : 527171584,
      "max" : 699072512,
      "used" : 0
    },
    "CollectionUsageThreshold" : 0,
    "CollectionUsageThresholdCount" : 0,
    "MemoryManagerNames" : [ "PS MarkSweep" ],
    "PeakUsage" : {
      "committed" : 527171584,
      "init" : 527171584,
      "max" : 699072512,
      "used" : 156468240
    },
    "Usage" : {
      "committed" : 527171584,
      "init" : 527171584,
      "max" : 699072512,
      "used" : 156468240
    },
    "UsageThreshold" : 0,
    "UsageThresholdCount" : 0,
    "CollectionUsageThresholdExceeded" : true,
    "CollectionUsageThresholdSupported" : true,
    "UsageThresholdExceeded" : true,
    "UsageThresholdSupported" : true
  }, {
    "name" : "java.lang:type=MemoryManager,name=CodeCacheManager",
    "modelerType" : "sun.management.MemoryManagerImpl",
    "Name" : "CodeCacheManager",
    "Valid" : true,
    "MemoryPoolNames" : [ "Code Cache" ]
  }, {
    "name" : "JMImplementation:type=MBeanServerDelegate",
    "modelerType" : "javax.management.MBeanServerDelegate",
    "MBeanServerId" : "c0805.hal.cloudera.com_1350410711432",
    "SpecificationName" : "Java Management Extensions",
    "SpecificationVersion" : "1.4",
    "SpecificationVendor" : "Sun Microsystems",
    "ImplementationName" : "JMX",
    "ImplementationVersion" : "1.6.0_31-b04",
    "ImplementationVendor" : "Sun Microsystems"
  }, {
    "name" : "Hadoop:service=JournalNode,name=MetricsSystem,sub=Stats",
    "modelerType" : "MetricsSystem,sub=Stats",
    "tag.Context" : "metricssystem",
    "tag.Hostname" : "c0805.hal.cloudera.com",
    "NumActiveSources" : 5,
    "NumAllSources" : 5,
    "NumActiveSinks" : 0,
    "NumAllSinks" : 0,
    "SnapshotNumOps" : 0,
    "SnapshotAvgTime" : 0.0,
    "PublishNumOps" : 0,
    "PublishAvgTime" : 0.0,
    "DroppedPubAll" : 0
  } ]
}
"""
